@@ -1,4 +1,4 @@
-/* GKRELLMWireless 0.2.1
+/* GKRELLMWireless
 |  Copyright (C) 2000-2001 Sjoerd Simons
 |
 |  Author:  Sjoerd Simons sjoerd@gkrellm.luon.net
@@ -89,8 +89,8 @@ wcard_t *found_wcard(gchar *interface) {
 }
 
 /* system specific stuff */
-#ifdef __FreeBSD__
-/* FreeBSD specific */
+#if defined(__FreeBSD__) || defined(__NetBSD__)
+/* FreeBSD & NetBSD specific */
 
 static int
 find_wi_card(void) {
@@ -131,6 +131,7 @@ find_wi_card(void) {
   return ret;
 }
 
+#if !defined(__NetBSD__)
 static gint
 find_an_card(void) {
   char interfaces[][4] = {"an0","an1","an2"};
@@ -158,13 +159,17 @@ find_an_card(void) {
   close(s);
   return ret;
 }
+#endif /* !defined(__NetBSD__) */
 
 static gint 
 find_wlancard(void) {
   gint ret = FALSE;
  
   ret = find_wi_card();
-  return find_an_card() || ret;
+#if !defined(__NetBSD__)
+  ret = find_an_card() || ret;
+#endif /* !defined(__NetBSD__) */
+  return ret;
 }
 
 static int
@@ -205,6 +210,7 @@ get_wi_link_quality(wcard_t *card, float *quality, float *level, float *noise) {
  return TRUE;
 }
 
+#if !defined(__NetBSD__)
 static int
 get_an_link_quality(wcard_t *card, float *quality, float *level, float *noise) {
   int nr,s;
@@ -245,12 +251,15 @@ get_an_link_quality(wcard_t *card, float *quality, float *level, float *noise) {
   *noise = sc->noise;
   return TRUE;
 }
+#endif /* !defined(__NetBSD__) */
 
 static int
 get_link_quality(wcard_t *card, float *quality, float *level, float *noise) {
   switch (card->ifname[0]) { 
+#if !defined(__NetBSD__)
     case 'a': /* an card */
       return get_an_link_quality(card,quality,level,noise);
+#endif /* !defined(__NetBSD__) */
     case 'w': /* wi card */
       return get_wi_link_quality(card,quality,level,noise);
   }
